import { Space, Table, Button, Image, Divider, Card, Input, TreeSelect  } from 'antd';
import type { TableColumnsType } from 'antd';
import { t } from '@/utils/i18n';
import React, { useState } from 'react';
import mData from '../../../../../mock/findDiySpecimenPage.json'
import shapeData from '../../../../../mock/findSpecimensByPrototypeId.json'
import { PlusOutlined, ExclamationCircleFilled, CarryOutOutlined } from '@ant-design/icons';
import type { ShapeProperty, Shape, ProductImage } from '@/models'
import { antdUtils } from '@/utils/antd';

const treeData = [
  {
    value: 'parent 1',
    title: 'parent 1',
    icon: <CarryOutOutlined />,
    children: [
      {
        value: 'parent 1-0',
        title: 'parent 1-0',
        icon: <CarryOutOutlined />,
        children: [
          {
            value: 'leaf1',
            title: 'leaf1',
            icon: <CarryOutOutlined />,
          },
          {
            value: 'leaf2',
            title: 'leaf2',
            icon: <CarryOutOutlined />,
          },
        ],
      },
      {
        value: 'parent 1-1',
        title: 'parent 1-1',
        icon: <CarryOutOutlined />,
        children: [
          {
            value: 'sss',
            title: 'sss',
            icon: <CarryOutOutlined />,
          },
        ],
      },
    ],
  },
];


const ShapePage: React.FC = () => {

  const showDeleteConfirm = (item: Shape) => {
    antdUtils.modal?.confirm({
      title: `确认删除标题为: ${item.sdParamEmplate.chinaName} 的素材吗?`,
      icon: <ExclamationCircleFilled />,
      content: '请注意删除以后不可恢复！',
      okText: '删除',
      okType: 'danger',
      cancelText: '取消',
      onOk() {
        return new Promise((resolve, reject) => {
          setTimeout(() => {
            antdUtils.message?.open({
              type: 'success',
              content: '删除成功',
            });
            resolve(null)
          }, 1000);

        }).catch(() => antdUtils.message?.open({
          type: 'error',
          content: '操作失败',
        }));
      },
      onCancel() {
      },
    });
  };

  const columns: TableColumnsType<ShapeProperty> = [
    {
      title: '示例图',
      dataIndex: 'oneImgUrl',
      key: 'oneImgUrl',
      render: (value: string) => (
        <Image className='bg-[gold] w-[40px] h-[40px]' src={value} />
      ),
      align: 'center',
      width: 100,
    },
    {
      title: 'SPU编码',
      dataIndex: 'spuCode',
      key: 'spuCode',
      width: 150,
    },
    {
      title: '样机名称',
      dataIndex: 'prototypeName',
      key: 'prototypeName',
      width: 200,
    },
    {
      title: '类目',
      key: 'categoryName',
      dataIndex: 'categoryName',
      width: 150,
    },
    {
      title: '款式数量',
      key: 'specimenNumber',
      dataIndex: 'specimenNumber',
      width: 100,
      render: (value: number) => (<>{value}</>)
    },
    {
      title: '创建人',
      dataIndex: 'createName',
      key: 'createName',
      width: 150,
    },
    {
      title: '创建时间',
      key: 'createTime',
      dataIndex: 'createTime',
      width: 200,
    },
    {
      title: t("QkOmYwne" /* 操作 */),
      key: 'action',
      render: (_, record) => (
        <Space size="middle" split={(
          <Divider type='vertical' />
        )}>
          <a
            onClick={() => {

            }}>
            添加款式
          </a>
        </Space>
      ),
    },
  ];

  const expandedColumnsRender = (item: ShapeProperty) => {
    const expandedColumns: TableColumnsType<Shape> = [
      { title: '序号', key: 'index', align: 'center', render: (data, _, index) => (<>{index}</>) },
      {
        title: '主图', dataIndex: ['product', 'productImgs'], key: 'productImgs', width: 100, render: (value: ProductImage[]) => (
          value.length > 0 && <Image className='bg-[gold] align-middle flex items-center justify-center w-[40px] h-[40px]' src={value[0].imgUrl} />
        )
      },
      { title: 'SPU', dataIndex: ['product', 'spuCode'], key: 'spuCode' },
      { title: '商品标题', dataIndex: ['product', 'base', 'productName'], key: 'productName' },
      { title: '背景词', dataIndex: ['sdParamEmplate', 'chinaName'], key: 'chinaName' },
      { title: '商品状态', dataIndex: 'upgradeNum', key: 'status' },
      { title: '数据来源', dataIndex: ['product', 'sourceType'], key: 'sourceType', render: (value: number) => (<>diy导入</>) },
      { title: '创建人', dataIndex: ['product', 'creatorName'], key: 'creatorName' },
      {
        title: t("QkOmYwne" /* 操作 */),
        key: 'operation',
        render: (_, record) => (
          <Space size="middle">
            <a>审核</a>
            <a>编辑</a>
            <a
             onClick={() => {showDeleteConfirm(record)}}>删除</a>
          </Space>
        ),
      },
    ];
    const data: Array<Shape> = shapeData as Array<Shape>;
    return <Table columns={expandedColumns} dataSource={data} pagination={false} />;
  }

  const data: Array<ShapeProperty> = mData as Array<ShapeProperty>;
  const [treeLine, setTreeLine] = useState(true);
  const [showLeafIcon, setShowLeafIcon] = useState(false);
  const [showIcon, setShowIcon] = useState<boolean>(false);
  return (
    <>
      <Card className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]' bodyStyle={{paddingTop: 4, paddingBottom:4 }}>
      <div className='flex justify-between content-center'>
            <div className='flex justify-normal items-center'>
              <TreeSelect
                treeDataSimpleMode
                style={{ width: '100%' }}
                dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                treeLine={treeLine && { showLeafIcon }}
                treeData={treeData}
                treeIcon={showIcon}
                size='large'
                placeholder="请选择类目"
              />
              <Input className='ml-[10px]'
                placeholder='请输入样机名称'/>
              <Button className="ml-5" type='primary' size='large'> 搜索 </Button>
              <Button className="ml-2" danger size='large'> 重置 </Button>
            </div>
            <div className="py-[4px]">
              <Button className="ml-5" type='primary' icon={<PlusOutlined />}> 新增款式 </Button>
            </div>
          </div>
      </Card>
      <Card className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'>
          <Table rowKey="id"
            scroll={{ x: true }}
            columns={columns}
            expandable={{ expandedRowRender: expandedColumnsRender, defaultExpandedRowKeys: ['0'] }}
            dataSource={data}
            className='bg-transparent'
            pagination={{ position: ['bottomRight'] }} />
        </Card>
    </>
  );
};

export default ShapePage;
